import yargs from 'yargs';
import { hideBin } from 'yargs/helpers';
import { createAiClient } from './app';
import { addEvents } from './events';

export type Argv = Record<string, unknown>;

const main = (argv: Argv) => new Promise<number>((resolve) => {
  const aiClient = createAiClient();
  const onResolve = (result: unknown) => {
    console.log(result);
    resolve(0);
  };

  const onReject = (error: Error) => {
    console.error(error);
    resolve(-1);
  };

  addEvents(aiClient, onResolve, onReject);
  console.log(argv);
  resolve(0);
});

main(yargs(hideBin(process.argv)).argv as unknown as Argv)
  .then((result) => {
    process.exit(result);
  })
  .catch((error) => {
    console.error(error);
    process.exit(-1);
  });
